@@ -1,42 +1,27 @@
 mod config;
 #[cfg(test)]
 mod test;
-use self::config::Config;
-
-use super::Backend;
-use crate::ast;
-use crate::complete;
-use crate::consts::TREESITTER_CMAKE_LANGUAGE;
-use crate::document_link;
-use crate::fileapi;
-use crate::fileapi::DEFAULT_QUERY;
-use crate::filewatcher;
-use crate::formatting::getformat;
-use crate::gammar::checkerror;
-use crate::gammar::ErrorInformation;
-use crate::gammar::LintConfigInfo;
-use crate::hover;
-use crate::jump;
-use crate::scansubs;
-use crate::semantic_token;
-use crate::semantic_token::LEGEND_TYPE;
-use crate::utils;
-use crate::utils::did_vcpkg_project;
-use crate::utils::treehelper;
-use crate::utils::VCPKG_LIBS;
-use crate::utils::VCPKG_PREFIX;
 use std::collections::HashMap;
-use std::sync::Arc;
-use std::sync::RwLock;
+use std::sync::{Arc, LazyLock, RwLock};
+
 use tokio::sync::Mutex;
-use tower_lsp::jsonrpc::Error as LspError;
-use tower_lsp::jsonrpc::Result;
-use tower_lsp::lsp_types;
+use tower_lsp::jsonrpc::{Error as LspError, Result};
 use tower_lsp::lsp_types::*;
-use tower_lsp::LanguageServer;
+use tower_lsp::{lsp_types, LanguageServer};
 use tree_sitter::Parser;
 
-use std::sync::LazyLock;
+use self::config::Config;
+use super::Backend;
+use crate::consts::TREESITTER_CMAKE_LANGUAGE;
+use crate::fileapi::DEFAULT_QUERY;
+use crate::formatting::getformat;
+use crate::gammar::{checkerror, ErrorInformation, LintConfigInfo};
+use crate::semantic_token::LEGEND_TYPE;
+use crate::utils::{did_vcpkg_project, treehelper, VCPKG_LIBS, VCPKG_PREFIX};
+use crate::{
+    ast, complete, document_link, fileapi, filewatcher, hover, jump, scansubs, semantic_token,
+    utils,
+};
 
 pub static BUFFERS_CACHE: LazyLock<Arc<Mutex<HashMap<lsp_types::Url, String>>>> =
     LazyLock::new(|| Arc::new(Mutex::new(HashMap::new())));
@@ -167,10 +152,12 @@ impl LanguageServer for Backend {
                     watch_file.dynamic_registration,
                     watch_file.relative_pattern_support,
                 ) {
+                    // NOTE: I think it only contains one workspace
                     if let Some(ref top_path) = initial
-                        .root_uri
+                        .workspace_folders
                         .as_ref()
-                        .and_then(|uri| uri.to_file_path().ok())
+                        .and_then(|folders| folders.first())
+                        .and_then(|folder| folder.uri.to_file_path().ok())
                     {
                         let path = top_path.join("build").join("CMakeCache.txt");
                         if path.exists() {
@@ -211,9 +198,10 @@ impl LanguageServer for Backend {
         }
 
         if let Some(ref vcpkg_root) = initial
-            .root_uri
+            .workspace_folders
             .as_ref()
-            .and_then(|uri| uri.to_file_path().ok())
+            .and_then(|folders| folders.first())
+            .and_then(|folder| folder.uri.to_file_path().ok())
         {
             scansubs::scan_all(&vcpkg_root).await;
             let mut root_path = self.root_path.lock().await;
